@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#undef LOCAL_DEBUG
+#define LOCAL_DEBUG
 #undef DO_CLOCKING
 #ifndef NO_DEBUG_OUTPUT
 #undef DEBUG_RECTS
@@ -75,6 +75,12 @@ ASVisual *_set_default_asvisual( ASVisual *new_v )
 {
 	ASVisual *old_v = __as_default_asvisual ;
 	__as_default_asvisual = new_v?new_v:&__as_dummy_asvisual ;
+/* This should be done in application - we should not meddle with other lib's stuff! 
+#if HAVE_AFTERBASE_FLAG	
+	if (new_v && new_v->dpy && !get_current_X_display (new_v->dpy))
+		set_current_X_display (new_v->dpy);
+#endif
+*/
 	return old_v;
 }
 
@@ -390,7 +396,7 @@ asimage_destroy (ASHashableValue value, void *data)
 			else
 				im->imageman = NULL ;
 		}
-		if( (char*)value != im->name ) 
+		if( im == NULL || (char*)value != im->name ) 
 			free( (char*)value );/* name */
 		destroy_asimage( &im );
 	}
@@ -1101,7 +1107,6 @@ vectorize_asimage( ASImage *im, unsigned int max_colors, unsigned int dither,
 	ASVectorPalette* pal ;
 	double *vec ;
 	ASColormap cmap;
-	int *res;
     unsigned int r, g, b, v;
 	unsigned int x, y, j ;
 
@@ -1112,20 +1117,25 @@ vectorize_asimage( ASImage *im, unsigned int max_colors, unsigned int dither,
 	/* contributed by Valeriy Onuchin from Root project at cern.ch */   
 
  	dither = dither > 7 ? 7 : dither;
- 	res = colormap_asimage(im, &cmap, max_colors, dither, opaque_threshold);
+	{
+ 		int *res = colormap_asimage(im, &cmap, max_colors, dither, opaque_threshold);
  
-    for ( y = 0; y < im->height; y++) {
-       for ( x = 0; x < im->width; x++) {
-          int i = y*im->width + x;
-          g = INDEX_SHIFT_GREEN(cmap.entries[res[i]].green);
-          b = INDEX_SHIFT_BLUE(cmap.entries[res[i]].blue);
-          r = INDEX_SHIFT_RED(cmap.entries[res[i]].red);
-          v = MAKE_INDEXED_COLOR24(r,g,b);
-          v = (v>>12)&0x0FFF;
-          vec[(im->height - y - 1)*im->width + x] = ((double)v)/0x0FFF;
-       }
-    }
-
+    	for ( y = 0; y < im->height; y++) 
+		{
+       		for ( x = 0; x < im->width; x++) 
+			{
+          		int i = y*im->width + x;
+          		g = INDEX_SHIFT_GREEN(cmap.entries[res[i]].green);
+          		b = INDEX_SHIFT_BLUE(cmap.entries[res[i]].blue);
+          		r = INDEX_SHIFT_RED(cmap.entries[res[i]].red);
+          		v = MAKE_INDEXED_COLOR24(r,g,b);
+		        v = (v>>12)&0x0FFF;
+          		vec[(im->height - y - 1)*im->width + x] = ((double)v)/0x0FFF;
+       		}
+    	}
+	
+		free (res);
+	}
     pal = safecalloc( 1, sizeof(ASVectorPalette));
 
 	pal->npoints = cmap.count ;	
